repository

package
v1.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2026 License: Apache-2.0 Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewAuditEventRepo

func NewAuditEventRepo(db *sqlc.Queries) domain.AuditEventRepo

func NewCleanupRepo

func NewCleanupRepo(queries *sqlc.Queries) messaging.CleanupRepo

NewCleanupRepo creates a new cleanup repository for the idempotency key cleanup worker.

func NewFailureMonitorRepo added in v1.2.0

func NewFailureMonitorRepo(queries *sqlc.Queries) messaging.FailureMonitorRepo

NewFailureMonitorRepo creates the repository the message failure monitor uses to scan the shared message_inbox and message_outbox tables for un-alerted failures and mark them alerted.

func NewIdempotencyKeyRepo

func NewIdempotencyKeyRepo(db *sql.DB, shared *sqlc.Queries) domain.IdempotencyKeyRepo

func NewInboxPurgerRepo

func NewInboxPurgerRepo(queries *sqlc.Queries) messaging.InboxPurgerRepo

func NewInboxRepo

func NewInboxRepo(queries *sqlc.Queries) messaging.InboxRepo

func NewLeaseRepo

func NewLeaseRepo(queries *sqlc.Queries) lease.Repo

NewLeaseRepo creates a lease repository backed by the service's MySQL connection.

func NewOutboxEnqueuerRepo

func NewOutboxEnqueuerRepo(dbPool *sql.DB, queries *sqlc.Queries) messaging.OutboxEnqueuerRepo

NewOutboxEnqueuerRepo creates a new outbox repository for the enqueuer. It requires both the db pool (for transactions) and queries (for non-transactional operations).

func NewOutboxRepo

func NewOutboxRepo(queries *sqlc.Queries) messaging.OutboxRepo

NewOutboxRepo creates the producer-side outbox repository used by services to enqueue messages.

func NewRepoFactory

func NewRepoFactory(db *sqlc.Queries) domain.RepoFactory

func NewRequestLogRepo

func NewRequestLogRepo(db *sqlc.Queries) domain.RequestLogRepo

Types

This section is empty.

Jump to